@@ -128,7 +128,7 @@ class LMFC(Module):
 # Core TX ------------------------------------------------------------------------------------------
 
 class LiteJESD204BCoreTX(Module):
-    def __init__(self, phys, jesd_settings, converter_data_width):
+    def __init__(self, phys, jesd_settings, converter_data_width, scrambling=True, stpl_random=True):
         self.enable  = Signal()
         self.jsync   = Signal()
         self.jref    = Signal()
@@ -147,7 +147,7 @@ class LiteJESD204BCoreTX(Module):
         self.submodules.transport = transport
 
         # STPL
-        stpl = LiteJESD204BSTPLGenerator(jesd_settings, converter_data_width)
+        stpl = LiteJESD204BSTPLGenerator(jesd_settings, converter_data_width, random=stpl_random)
         stpl = ClockDomainsRenamer("jesd")(stpl)
         self.submodules.stpl = stpl
         self.comb += \
@@ -178,6 +178,7 @@ class LiteJESD204BCoreTX(Module):
             links.append(link)
             self.comb += [
                 link.reset.eq(~self.enable),
+                link.datapath.scrambler.enable.eq(int(scrambling)),
                 link.jsync.eq(self.jsync),
                 link.jref.eq(self.jref),
                 link.lmfc_zero.eq(self.lmfc.zero),
@@ -221,7 +222,7 @@ class LiteJESD204BCoreTX(Module):
 # Core RX ------------------------------------------------------------------------------------------
 
 class LiteJESD204BCoreRX(Module):
-    def __init__(self, phys, jesd_settings, converter_data_width, ilas_check=True):
+    def __init__(self, phys, jesd_settings, converter_data_width, scrambling=True, ilas_check=True, stpl_random=True):
         self.enable  = Signal()
         self.jsync   = Signal()
         self.jref    = Signal()
@@ -240,7 +241,7 @@ class LiteJESD204BCoreRX(Module):
         self.submodules.transport = transport
 
         # STPL
-        stpl = LiteJESD204BSTPLChecker(jesd_settings, converter_data_width)
+        stpl = LiteJESD204BSTPLChecker(jesd_settings, converter_data_width, stpl_random)
         stpl = ClockDomainsRenamer("jesd")(stpl)
         self.submodules.stpl = stpl
         self.comb += \
@@ -272,6 +273,7 @@ class LiteJESD204BCoreRX(Module):
             links.append(link)
             self.comb += [
                 link.reset.eq(~self.enable),
+                link.datapath.descrambler.enable.eq(int(scrambling)),
                 link.jref.eq(self.jref),
                 link.lmfc_zero.eq(self.lmfc.zero),
                 phy.rx_align.eq(link.align)
@@ -330,12 +332,12 @@ class LiteJESD204BCoreRX(Module):
 # Core Control ----------------------------------------------------------------------------------
 
 class LiteJESD204BCoreControl(Module, AutoCSR):
-    def __init__(self, core, sys_clk_freq):
+    def __init__(self, core, sys_clk_freq, default_enable=0, default_stpl_enable=0):
         self.control = CSRStorage(fields=[
             CSRField("enable", size=1, values=[
                 ("``0b0``", "JESD core disabled."),
                 ("``0b1``", "JESD core enabled.")
-            ])
+            ], reset=default_enable)
         ])
         self.status = CSRStatus(fields=[
             CSRField("ready", size=1, offset=0, values=[
@@ -349,7 +351,7 @@ class LiteJESD204BCoreControl(Module, AutoCSR):
             CSRField("enable", size=1, offset=0, values=[
                 ("``0b0``", "STPL test disabled."),
                 ("``0b1``", "STPL test enabled.")
-            ])
+            ], reset=default_stpl_enable)
         ])
         self.stpl_errors = CSRStatus(32, description="STPL test errors.")
         self.lmfc        = CSRStorage(fields=[
